@@ -1,7 +1,7 @@
 /*
  * symbol - global and local symbol routines
  *
- * Copyright (C) 1999  David I. Bell
+ * Copyright (C) 1999-2007,2014  David I. Bell
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -15,11 +15,11 @@
  * A copy of version 2.1 of the GNU Lesser General Public License is
  * distributed with calc under the filename COPYING-LGPL.  You should have
  * received a copy with calc; if not, write to Free Software Foundation, Inc.
- * 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * @(#) $Revision: 29.4 $
- * @(#) $Id: symbol.h,v 29.4 2001/06/08 21:00:58 chongo Exp $
- * @(#) $Source: /usr/local/src/cmd/calc/RCS/symbol.h,v $
+ * @(#) $Revision: 30.3 $
+ * @(#) $Id: symbol.h,v 30.3 2014/08/24 21:56:51 chongo Exp $
+ * @(#) $Source: /usr/local/src/bin/calc/RCS/symbol.h,v $
  *
  * Under source code control:	1990/02/15 01:48:37
  * File existed as early as:	before 1990
@@ -28,8 +28,8 @@
  */
 
 
-#if !defined(__SYMBOL_H__)
-#define __SYMBOL_H__
+#if !defined(INCLUDE_SYMBOL_H)
+#define INCLUDE_SYMBOL_H
 
 
 #if defined(CALC_SRC)	/* if we are building from the calc source tree */
@@ -54,7 +54,7 @@
 
 typedef struct global GLOBAL;
 struct global {
-	int g_len;		/* length of symbol name */
+	size_t g_len;		/* length of symbol name */
 	short g_filescope;	/* file scope level of symbol (0 if global) */
 	short g_funcscope;	/* function scope level of symbol */
 	char *g_name;		/* global symbol name */
@@ -66,45 +66,45 @@ struct global {
 /*
  * Routines to search for global symbols.
  */
-extern GLOBAL *addglobal(char *name, BOOL isstatic);
-extern GLOBAL *findglobal(char *name);
+E_FUNC GLOBAL *addglobal(char *name, BOOL isstatic);
+E_FUNC GLOBAL *findglobal(char *name);
 
 
 /*
  * Routines to return names of variables.
  */
-extern char *localname(long n);
-extern char *paramname(long n);
-extern char *globalname(GLOBAL *sp);
+E_FUNC char *localname(long n);
+E_FUNC char *paramname(long n);
+E_FUNC char *globalname(GLOBAL *sp);
 
 
 /*
  * Routines to handle entering and leaving of scope levels.
  */
-extern void resetscopes(void);
-extern void enterfilescope(void);
-extern void exitfilescope(void);
-extern void enterfuncscope(void);
-extern void exitfuncscope(void);
-extern void endscope (char *name, BOOL isglobal);
+E_FUNC void resetscopes(void);
+E_FUNC void enterfilescope(void);
+E_FUNC void exitfilescope(void);
+E_FUNC void enterfuncscope(void);
+E_FUNC void exitfuncscope(void);
+E_FUNC void endscope (char *name, BOOL isglobal);
 
 
 /*
  * Other routines.
  */
-extern long addlocal(char *name);
-extern long findlocal(char *name);
-extern long addparam(char *name);
-extern long findparam(char *name);
-extern void initlocals(void);
-extern void initglobals(void);
-extern int writeglobals(char *name);
-extern int symboltype(char *name);
-extern void showglobals(void);
-extern void showallglobals(void);
-extern void freeglobals(void);
-extern void showstatics(void);
-extern void freestatics(void);
+E_FUNC long addlocal(char *name);
+E_FUNC long findlocal(char *name);
+E_FUNC long addparam(char *name);
+E_FUNC long findparam(char *name);
+E_FUNC void initlocals(void);
+E_FUNC void initglobals(void);
+E_FUNC int writeglobals(char *name);
+E_FUNC int symboltype(char *name);
+E_FUNC void showglobals(void);
+E_FUNC void showallglobals(void);
+E_FUNC void freeglobals(void);
+E_FUNC void showstatics(void);
+E_FUNC void freestatics(void);
 
 
-#endif /* !__SYMBOL_H__ */
+#endif /* !INCLUDE_SYMBOL_H */
